@@ -3,7 +3,8 @@ import unittest
 import numpy as np
 from pymatgen.core import Structure
 
-from pyg_extension.data.structuretodata import AddSAPymatgen, AddXPymatgen, AddXASE, StructureToData, AddXArray, \
+from pyg_extension.data.structuretodata import AddSAPymatgen, AddXPymatgen, AddXASE, \
+    StructureToData, AddXArray, \
     AddPBCEdgeDistance, AddPBCEdgeXYZ
 
 data = Structure.from_file("POSCAR")
